Uses the x coordinate and sign flag (+/-) to reconstruct the point.
The y coordinate can be derived from the x coordinate and the "sign" flag by solving the grumpkin curve
equation for y.
@param x - The x coordinate of the point
@param sign - The "sign" of the y coordinate - determines whether y <= (Fr.MODULUS - 1) / 2
Uses the x coordinate and sign flag (+/-) to reconstruct the point. The y coordinate can be derived from the x coordinate and the "sign" flag by solving the grumpkin curve equation for y. @param x - The x coordinate of the point @param sign - The "sign" of the y coordinate - determines whether y <= (Fr.MODULUS - 1) / 2